summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMichael Hamann <michael@content-space.de>2012-08-24 14:26:55 +0200
committerMichael Hamann <michael@content-space.de>2012-08-24 16:50:07 +0200
commit59f20ea39dc6e0e100f8a3a0b76079bfe81debeb (patch)
treeff7263ee1632858a836be3b937f82cbed4267dcf
parentd9764001b988720d7c633a2de6c2c5baf08cf665 (diff)
downloadrpg-59f20ea39dc6e0e100f8a3a0b76079bfe81debeb.tar.gz
rpg-59f20ea39dc6e0e100f8a3a0b76079bfe81debeb.tar.bz2
Fix types in inc/changelog.php and initialize variables
-rw-r--r--inc/changelog.php8
1 files changed, 6 insertions, 2 deletions
diff --git a/inc/changelog.php b/inc/changelog.php
index 24583b341..688aebfd6 100644
--- a/inc/changelog.php
+++ b/inc/changelog.php
@@ -157,7 +157,8 @@ function addMediaLogEntry($date, $id, $type=DOKU_CHANGE_TYPE_EDIT, $summary='',
* @param int $first number of first entry returned (for paginating
* @param int $num return $num entries
* @param string $ns restrict to given namespace
* @param bool $flags see above
*
* @author Ben Coburn <btcoburn@silicodon.net>
* @author Kate Arzamastseva <pshns@ukr.net>
@@ -177,6 +178,8 @@ function getRecents($first,$num,$ns='',$flags=0){
$lines = @file($conf['changelog']);
}
$lines_position = count($lines)-1;
+ $media_lines_position = 0;
+ $media_lines = array();
if ($flags & RECENTS_MEDIA_PAGES_MIXED) {
$media_lines = @file($conf['media_changelog']);
@@ -236,7 +239,8 @@ function getRecents($first,$num,$ns='',$flags=0){
* @param int $from date of the oldest entry to return
* @param int $to date of the newest entry to return (for pagination, optional)
* @param string $ns restrict to given namespace (optional)
* @param bool $flags see above (optional)
*
* @author Michael Hamann <michael@content-space.de>
* @author Ben Coburn <btcoburn@silicodon.net>
@@ -157,7 +157,8 @@ function addMediaLogEntry($date, $id, $type=DOKU_CHANGE_TYPE_EDIT, $summary='',
* @param int $num return $num entries
* @param string $ns restrict to given namespace
- * @param bool $flags see above
+ * @param int $flags see above
+ * @return array recently changed files
*
* @author Ben Coburn <btcoburn@silicodon.net>
@@ -236,7 +239,8 @@ function getRecents($first,$num,$ns='',$flags=0){
* @param int $to date of the newest entry to return (for pagination, optional)
* @param string $ns restrict to given namespace (optional)
- * @param bool $flags see above (optional)
+ * @param int $flags see above (optional)
+ * @return array of files
*
* @author Michael Hamann <michael@content-space.de>